@@ -2,10 +2,13 @@ import multiprocessing
 import os
 
 
-def shell(cmd, working_directory='.', stdout=False, stderr=False):
+def shell(cmd, working_directory='.', stdout=False, stderr=False, verbose=True):
     import subprocess
     from subprocess import PIPE, Popen
 
+    if verbose:
+        print("[Info] Starting to run this command now:", cmd)
+
     subp = Popen(cmd, shell=True, stdout=PIPE,
                  stderr=subprocess.STDOUT, cwd=working_directory)
     subp_stdout, subp_stderr = subp.communicate()
@@ -21,6 +24,7 @@ def shell(cmd, working_directory='.', stdout=False, stderr=False):
     return subp_stdout, subp_stderr
 
 
+
 def mproc(func, input_list, avail_cpu=multiprocessing.cpu_count() - 4):
     '''
     This is a multiprocess function where you execute the function with 
